Module init

Module init 

init.rs - Initialization Module for horon-engine storage

Provides functions for initializing and managing hyperbolic tree tensor (HTT) storage instances.

Functions

initialize_htt_storage
Initialize HTT storage with a configuration.
with_htt
Execute a function with access to a shared HTT instance.