pub struct KleinPoint {
pub coords: FixedVector,
pub weight: FixedPoint,
}Expand description
A point in the Klein projective model of hyperbolic space.
In the Klein model, geodesics are Euclidean straight lines (chords), which makes power diagram bisectors into Euclidean hyperplanes.
Fields
coords: FixedVectorKlein disk coordinates (||coords|| < 1)
weight: FixedPointPower weight: w = 1 - ||coords||²
Implementations
Sourceimpl KleinPoint
impl KleinPoint